*****
Solar
*****

.. |br| raw:: html

   <br />

.. automodule:: aristopy.solar

SolarData
==========

.. autoclass:: SolarData
   :members:
   :undoc-members:


SolarThermalCollector
=====================
   
.. autoclass:: SolarThermalCollector
   :members:
   :undoc-members:

   
PVSystem
========

.. autoclass:: PVSystem
   :members:
   :undoc-members: